# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/listener/v4alpha/udp_default_writer_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/listener/v4alpha/udp_default_writer_config.proto',
  package='envoy.config.listener.v4alpha',
  syntax='proto3',
  serialized_options=b'\n+io.envoyproxy.envoy.config.listener.v4alphaB\033UdpDefaultWriterConfigProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=envoy/config/listener/v4alpha/udp_default_writer_config.proto\x12\x1d\x65nvoy.config.listener.v4alpha\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"R\n\x17UdpDefaultWriterOptions:7\x9a\xc5\x88\x1e\x32\n0envoy.config.listener.v3.UdpDefaultWriterOptionsBT\n+io.envoyproxy.envoy.config.listener.v4alphaB\x1bUdpDefaultWriterConfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_UDPDEFAULTWRITEROPTIONS = _descriptor.Descriptor(
  name='UdpDefaultWriterOptions',
  full_name='envoy.config.listener.v4alpha.UdpDefaultWriterOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0362\n0envoy.config.listener.v3.UdpDefaultWriterOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=244,
)

DESCRIPTOR.message_types_by_name['UdpDefaultWriterOptions'] = _UDPDEFAULTWRITEROPTIONS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UdpDefaultWriterOptions = _reflection.GeneratedProtocolMessageType('UdpDefaultWriterOptions', (_message.Message,), {
  'DESCRIPTOR' : _UDPDEFAULTWRITEROPTIONS,
  '__module__' : 'envoy.config.listener.v4alpha.udp_default_writer_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.listener.v4alpha.UdpDefaultWriterOptions)
  })
_sym_db.RegisterMessage(UdpDefaultWriterOptions)


DESCRIPTOR._options = None
_UDPDEFAULTWRITEROPTIONS._options = None
# @@protoc_insertion_point(module_scope)
