# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/upstreams/tcp/generic/v3/generic_connection_pool.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/upstreams/tcp/generic/v3/generic_connection_pool.proto',
  package='envoy.extensions.upstreams.tcp.generic.v3',
  syntax='proto3',
  serialized_options=b'\n7io.envoyproxy.envoy.extensions.upstreams.tcp.generic.v3B$GenericConnectionPoolProtoOuterClassP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nGenvoy/extensions/upstreams/tcp/generic/v3/generic_connection_pool.proto\x12)envoy.extensions.upstreams.tcp.generic.v3\x1a\x1dudpa/annotations/status.proto\"\x1c\n\x1aGenericConnectionPoolProtoBi\n7io.envoyproxy.envoy.extensions.upstreams.tcp.generic.v3B$GenericConnectionPoolProtoOuterClassP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_GENERICCONNECTIONPOOLPROTO = _descriptor.Descriptor(
  name='GenericConnectionPoolProto',
  full_name='envoy.extensions.upstreams.tcp.generic.v3.GenericConnectionPoolProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=177,
)

DESCRIPTOR.message_types_by_name['GenericConnectionPoolProto'] = _GENERICCONNECTIONPOOLPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenericConnectionPoolProto = _reflection.GeneratedProtocolMessageType('GenericConnectionPoolProto', (_message.Message,), {
  'DESCRIPTOR' : _GENERICCONNECTIONPOOLPROTO,
  '__module__' : 'envoy.extensions.upstreams.tcp.generic.v3.generic_connection_pool_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.upstreams.tcp.generic.v3.GenericConnectionPoolProto)
  })
_sym_db.RegisterMessage(GenericConnectionPoolProto)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
