# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/listener/v3/lds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/listener/v3/lds.proto',
  package='envoy.service.listener.v3',
  syntax='proto3',
  serialized_options=b'\n\'io.envoyproxy.envoy.service.listener.v3B\010LdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#envoy/service/listener/v3/lds.proto\x12\x19\x65nvoy.service.listener.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"(\n\x08LdsDummy:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.api.v2.LdsDummy2\xd4\x03\n\x18ListenerDiscoveryService\x12}\n\x0e\x44\x65ltaListeners\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12t\n\x0fStreamListeners\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12\x97\x01\n\x0e\x46\x65tchListeners\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"(\x82\xd3\xe4\x93\x02\x19\"\x17/v3/discovery:listeners\x82\xd3\xe4\x93\x02\x03:\x01*\x1a)\x8a\xa4\x96\xf3\x07#\n!envoy.config.listener.v3.ListenerB@\n\'io.envoyproxy.envoy.service.listener.v3B\x08LdsProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_LDSDUMMY = _descriptor.Descriptor(
  name='LdsDummy',
  full_name='envoy.service.listener.v3.LdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.api.v2.LdsDummy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=280,
)

DESCRIPTOR.message_types_by_name['LdsDummy'] = _LDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LdsDummy = _reflection.GeneratedProtocolMessageType('LdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _LDSDUMMY,
  '__module__' : 'envoy.service.listener.v3.lds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.listener.v3.LdsDummy)
  })
_sym_db.RegisterMessage(LdsDummy)


DESCRIPTOR._options = None
_LDSDUMMY._options = None

_LISTENERDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ListenerDiscoveryService',
  full_name='envoy.service.listener.v3.ListenerDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007#\n!envoy.config.listener.v3.Listener',
  create_key=_descriptor._internal_create_key,
  serialized_start=283,
  serialized_end=751,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeltaListeners',
    full_name='envoy.service.listener.v3.ListenerDiscoveryService.DeltaListeners',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamListeners',
    full_name='envoy.service.listener.v3.ListenerDiscoveryService.StreamListeners',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchListeners',
    full_name='envoy.service.listener.v3.ListenerDiscoveryService.FetchListeners',
    index=2,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\"\027/v3/discovery:listeners\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LISTENERDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ListenerDiscoveryService'] = _LISTENERDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
