# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/api/v2/rds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2 import discovery_pb2 as envoy_dot_api_dot_v2_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from envoy.api.v2 import route_pb2 as envoy_dot_api_dot_v2_dot_route__pb2

from envoy.api.v2.route_pb2 import *

DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/api/v2/rds.proto',
  package='envoy.api.v2',
  syntax='proto3',
  serialized_options=b'\n\032io.envoyproxy.envoy.api.v2B\010RdsProtoP\001\210\001\001\362\230\376\217\005\030\022\026envoy.service.route.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16\x65nvoy/api/v2/rds.proto\x12\x0c\x65nvoy.api.v2\x1a\x1c\x65nvoy/api/v2/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x18\x65nvoy/api/v2/route.proto\"\n\n\x08RdsDummy2\xee\x02\n\x15RouteDiscoveryService\x12U\n\x0cStreamRoutes\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"\x00(\x01\x30\x01\x12^\n\x0b\x44\x65ltaRoutes\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12u\n\x0b\x46\x65tchRoutes\x12\x1e.envoy.api.v2.DiscoveryRequest\x1a\x1f.envoy.api.v2.DiscoveryResponse\"%\x82\xd3\xe4\x93\x02\x16\"\x14/v2/discovery:routes\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\'\x8a\xa4\x96\xf3\x07!\n\x1f\x65nvoy.api.v2.RouteConfiguration2\xab\x01\n\x1bVirtualHostDiscoveryService\x12\x64\n\x11\x44\x65ltaVirtualHosts\x12#.envoy.api.v2.DeltaDiscoveryRequest\x1a$.envoy.api.v2.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x1a&\x8a\xa4\x96\xf3\x07 \n\x1e\x65nvoy.api.v2.route.VirtualHostBQ\n\x1aio.envoyproxy.envoy.api.v2B\x08RdsProtoP\x01\x88\x01\x01\xf2\x98\xfe\x8f\x05\x18\x12\x16\x65nvoy.service.route.v3\xba\x80\xc8\xd1\x06\x02\x10\x01P\x05\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_route__pb2.DESCRIPTOR,],
  public_dependencies=[envoy_dot_api_dot_v2_dot_route__pb2.DESCRIPTOR,])




_RDSDUMMY = _descriptor.Descriptor(
  name='RdsDummy',
  full_name='envoy.api.v2.RdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=233,
)

DESCRIPTOR.message_types_by_name['RdsDummy'] = _RDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RdsDummy = _reflection.GeneratedProtocolMessageType('RdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _RDSDUMMY,
  '__module__' : 'envoy.api.v2.rds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.api.v2.RdsDummy)
  })
_sym_db.RegisterMessage(RdsDummy)


DESCRIPTOR._options = None

_ROUTEDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='RouteDiscoveryService',
  full_name='envoy.api.v2.RouteDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007!\n\037envoy.api.v2.RouteConfiguration',
  create_key=_descriptor._internal_create_key,
  serialized_start=236,
  serialized_end=602,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamRoutes',
    full_name='envoy.api.v2.RouteDiscoveryService.StreamRoutes',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaRoutes',
    full_name='envoy.api.v2.RouteDiscoveryService.DeltaRoutes',
    index=1,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchRoutes',
    full_name='envoy.api.v2.RouteDiscoveryService.FetchRoutes',
    index=2,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\"\024/v2/discovery:routes\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROUTEDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['RouteDiscoveryService'] = _ROUTEDISCOVERYSERVICE


_VIRTUALHOSTDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='VirtualHostDiscoveryService',
  full_name='envoy.api.v2.VirtualHostDiscoveryService',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\212\244\226\363\007 \n\036envoy.api.v2.route.VirtualHost',
  create_key=_descriptor._internal_create_key,
  serialized_start=605,
  serialized_end=776,
  methods=[
  _descriptor.MethodDescriptor(
    name='DeltaVirtualHosts',
    full_name='envoy.api.v2.VirtualHostDiscoveryService.DeltaVirtualHosts',
    index=0,
    containing_service=None,
    input_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_api_dot_v2_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIRTUALHOSTDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['VirtualHostDiscoveryService'] = _VIRTUALHOSTDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)
