# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/alts/v3/alts.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/alts/v3/alts.proto',
  package='envoy.extensions.transport_sockets.alts.v3',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.extensions.transport_sockets.alts.v3B\tAltsProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5envoy/extensions/transport_sockets/alts/v3/alts.proto\x12*envoy.extensions.transport_sockets.alts.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x82\x01\n\x04\x41lts\x12#\n\x12handshaker_service\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x1d\n\x15peer_service_accounts\x18\x02 \x03(\t:6\x9a\xc5\x88\x1e\x31\n/envoy.config.transport_socket.alts.v2alpha.AltsBO\n8io.envoyproxy.envoy.extensions.transport_sockets.alts.v3B\tAltsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ALTS = _descriptor.Descriptor(
  name='Alts',
  full_name='envoy.extensions.transport_sockets.alts.v3.Alts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='handshaker_service', full_name='envoy.extensions.transport_sockets.alts.v3.Alts.handshaker_service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peer_service_accounts', full_name='envoy.extensions.transport_sockets.alts.v3.Alts.peer_service_accounts', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.config.transport_socket.alts.v2alpha.Alts',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=193,
  serialized_end=323,
)

DESCRIPTOR.message_types_by_name['Alts'] = _ALTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Alts = _reflection.GeneratedProtocolMessageType('Alts', (_message.Message,), {
  'DESCRIPTOR' : _ALTS,
  '__module__' : 'envoy.extensions.transport_sockets.alts.v3.alts_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.alts.v3.Alts)
  })
_sym_db.RegisterMessage(Alts)


DESCRIPTOR._options = None
_ALTS.fields_by_name['handshaker_service']._options = None
_ALTS._options = None
# @@protoc_insertion_point(module_scope)
