# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/admin/v3/certs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/admin/v3/certs.proto',
  package='envoy.admin.v3',
  syntax='proto3',
  serialized_options=b'\n\034io.envoyproxy.envoy.admin.v3B\nCertsProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65nvoy/admin/v3/certs.proto\x12\x0e\x65nvoy.admin.v3\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"j\n\x0c\x43\x65rtificates\x12\x31\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32\x1b.envoy.admin.v3.Certificate:\'\x9a\xc5\x88\x1e\"\n envoy.admin.v2alpha.Certificates\"\xa2\x01\n\x0b\x43\x65rtificate\x12\x33\n\x07\x63\x61_cert\x18\x01 \x03(\x0b\x32\".envoy.admin.v3.CertificateDetails\x12\x36\n\ncert_chain\x18\x02 \x03(\x0b\x32\".envoy.admin.v3.CertificateDetails:&\x9a\xc5\x88\x1e!\n\x1f\x65nvoy.admin.v2alpha.Certificate\"\xe2\x03\n\x12\x43\x65rtificateDetails\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12?\n\x11subject_alt_names\x18\x03 \x03(\x0b\x32$.envoy.admin.v3.SubjectAlternateName\x12\x1d\n\x15\x64\x61ys_until_expiration\x18\x04 \x01(\x04\x12.\n\nvalid_from\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0f\x65xpiration_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x44\n\x0cocsp_details\x18\x07 \x01(\x0b\x32..envoy.admin.v3.CertificateDetails.OcspDetails\x1am\n\x0bOcspDetails\x12.\n\nvalid_from\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nexpiration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:-\x9a\xc5\x88\x1e(\n&envoy.admin.v2alpha.CertificateDetails\"\x83\x01\n\x14SubjectAlternateName\x12\r\n\x03\x64ns\x18\x01 \x01(\tH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x12\x14\n\nip_address\x18\x03 \x01(\tH\x00:/\x9a\xc5\x88\x1e*\n(envoy.admin.v2alpha.SubjectAlternateNameB\x06\n\x04nameB4\n\x1cio.envoyproxy.envoy.admin.v3B\nCertsProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_CERTIFICATES = _descriptor.Descriptor(
  name='Certificates',
  full_name='envoy.admin.v3.Certificates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='certificates', full_name='envoy.admin.v3.Certificates.certificates', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\"\n envoy.admin.v2alpha.Certificates',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=251,
)


_CERTIFICATE = _descriptor.Descriptor(
  name='Certificate',
  full_name='envoy.admin.v3.Certificate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ca_cert', full_name='envoy.admin.v3.Certificate.ca_cert', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cert_chain', full_name='envoy.admin.v3.Certificate.cert_chain', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036!\n\037envoy.admin.v2alpha.Certificate',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=416,
)


_CERTIFICATEDETAILS_OCSPDETAILS = _descriptor.Descriptor(
  name='OcspDetails',
  full_name='envoy.admin.v3.CertificateDetails.OcspDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valid_from', full_name='envoy.admin.v3.CertificateDetails.OcspDetails.valid_from', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='envoy.admin.v3.CertificateDetails.OcspDetails.expiration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=745,
  serialized_end=854,
)

_CERTIFICATEDETAILS = _descriptor.Descriptor(
  name='CertificateDetails',
  full_name='envoy.admin.v3.CertificateDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.admin.v3.CertificateDetails.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='envoy.admin.v3.CertificateDetails.serial_number', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject_alt_names', full_name='envoy.admin.v3.CertificateDetails.subject_alt_names', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='days_until_expiration', full_name='envoy.admin.v3.CertificateDetails.days_until_expiration', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valid_from', full_name='envoy.admin.v3.CertificateDetails.valid_from', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration_time', full_name='envoy.admin.v3.CertificateDetails.expiration_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ocsp_details', full_name='envoy.admin.v3.CertificateDetails.ocsp_details', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CERTIFICATEDETAILS_OCSPDETAILS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036(\n&envoy.admin.v2alpha.CertificateDetails',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=419,
  serialized_end=901,
)


_SUBJECTALTERNATENAME = _descriptor.Descriptor(
  name='SubjectAlternateName',
  full_name='envoy.admin.v3.SubjectAlternateName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dns', full_name='envoy.admin.v3.SubjectAlternateName.dns', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='envoy.admin.v3.SubjectAlternateName.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='envoy.admin.v3.SubjectAlternateName.ip_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.admin.v2alpha.SubjectAlternateName',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='name', full_name='envoy.admin.v3.SubjectAlternateName.name',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=904,
  serialized_end=1035,
)

_CERTIFICATES.fields_by_name['certificates'].message_type = _CERTIFICATE
_CERTIFICATE.fields_by_name['ca_cert'].message_type = _CERTIFICATEDETAILS
_CERTIFICATE.fields_by_name['cert_chain'].message_type = _CERTIFICATEDETAILS
_CERTIFICATEDETAILS_OCSPDETAILS.fields_by_name['valid_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATEDETAILS_OCSPDETAILS.fields_by_name['expiration'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATEDETAILS_OCSPDETAILS.containing_type = _CERTIFICATEDETAILS
_CERTIFICATEDETAILS.fields_by_name['subject_alt_names'].message_type = _SUBJECTALTERNATENAME
_CERTIFICATEDETAILS.fields_by_name['valid_from'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATEDETAILS.fields_by_name['expiration_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CERTIFICATEDETAILS.fields_by_name['ocsp_details'].message_type = _CERTIFICATEDETAILS_OCSPDETAILS
_SUBJECTALTERNATENAME.oneofs_by_name['name'].fields.append(
  _SUBJECTALTERNATENAME.fields_by_name['dns'])
_SUBJECTALTERNATENAME.fields_by_name['dns'].containing_oneof = _SUBJECTALTERNATENAME.oneofs_by_name['name']
_SUBJECTALTERNATENAME.oneofs_by_name['name'].fields.append(
  _SUBJECTALTERNATENAME.fields_by_name['uri'])
_SUBJECTALTERNATENAME.fields_by_name['uri'].containing_oneof = _SUBJECTALTERNATENAME.oneofs_by_name['name']
_SUBJECTALTERNATENAME.oneofs_by_name['name'].fields.append(
  _SUBJECTALTERNATENAME.fields_by_name['ip_address'])
_SUBJECTALTERNATENAME.fields_by_name['ip_address'].containing_oneof = _SUBJECTALTERNATENAME.oneofs_by_name['name']
DESCRIPTOR.message_types_by_name['Certificates'] = _CERTIFICATES
DESCRIPTOR.message_types_by_name['Certificate'] = _CERTIFICATE
DESCRIPTOR.message_types_by_name['CertificateDetails'] = _CERTIFICATEDETAILS
DESCRIPTOR.message_types_by_name['SubjectAlternateName'] = _SUBJECTALTERNATENAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Certificates = _reflection.GeneratedProtocolMessageType('Certificates', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATES,
  '__module__' : 'envoy.admin.v3.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.Certificates)
  })
_sym_db.RegisterMessage(Certificates)

Certificate = _reflection.GeneratedProtocolMessageType('Certificate', (_message.Message,), {
  'DESCRIPTOR' : _CERTIFICATE,
  '__module__' : 'envoy.admin.v3.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.Certificate)
  })
_sym_db.RegisterMessage(Certificate)

CertificateDetails = _reflection.GeneratedProtocolMessageType('CertificateDetails', (_message.Message,), {

  'OcspDetails' : _reflection.GeneratedProtocolMessageType('OcspDetails', (_message.Message,), {
    'DESCRIPTOR' : _CERTIFICATEDETAILS_OCSPDETAILS,
    '__module__' : 'envoy.admin.v3.certs_pb2'
    # @@protoc_insertion_point(class_scope:envoy.admin.v3.CertificateDetails.OcspDetails)
    })
  ,
  'DESCRIPTOR' : _CERTIFICATEDETAILS,
  '__module__' : 'envoy.admin.v3.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.CertificateDetails)
  })
_sym_db.RegisterMessage(CertificateDetails)
_sym_db.RegisterMessage(CertificateDetails.OcspDetails)

SubjectAlternateName = _reflection.GeneratedProtocolMessageType('SubjectAlternateName', (_message.Message,), {
  'DESCRIPTOR' : _SUBJECTALTERNATENAME,
  '__module__' : 'envoy.admin.v3.certs_pb2'
  # @@protoc_insertion_point(class_scope:envoy.admin.v3.SubjectAlternateName)
  })
_sym_db.RegisterMessage(SubjectAlternateName)


DESCRIPTOR._options = None
_CERTIFICATES._options = None
_CERTIFICATE._options = None
_CERTIFICATEDETAILS._options = None
_SUBJECTALTERNATENAME._options = None
# @@protoc_insertion_point(module_scope)
