# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/thrift/router/v2alpha1/router.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/thrift/router/v2alpha1/router.proto',
  package='envoy.config.filter.thrift.router.v2alpha1',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.config.filter.thrift.router.v2alpha1B\013RouterProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/config/filter/thrift/router/v2alpha1/router.proto\x12*envoy.config.filter.thrift.router.v2alpha1\x1a\x1dudpa/annotations/status.proto\"\x08\n\x06RouterBQ\n8io.envoyproxy.envoy.config.filter.thrift.router.v2alpha1B\x0bRouterProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,])




_ROUTER = _descriptor.Descriptor(
  name='Router',
  full_name='envoy.config.filter.thrift.router.v2alpha1.Router',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=142,
)

DESCRIPTOR.message_types_by_name['Router'] = _ROUTER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Router = _reflection.GeneratedProtocolMessageType('Router', (_message.Message,), {
  'DESCRIPTOR' : _ROUTER,
  '__module__' : 'envoy.config.filter.thrift.router.v2alpha1.router_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.thrift.router.v2alpha1.Router)
  })
_sym_db.RegisterMessage(Router)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
