# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/jwt_authn/v2alpha/config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import base_pb2 as envoy_dot_api_dot_v2_dot_core_dot_base__pb2
try:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2
except AttributeError:
  envoy_dot_api_dot_v2_dot_core_dot_socket__option__pb2 = envoy_dot_api_dot_v2_dot_core_dot_base__pb2.envoy.api.v2.core.socket_option_pb2
from envoy.api.v2.core import http_uri_pb2 as envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2
from envoy.api.v2.route import route_components_pb2 as envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/jwt_authn/v2alpha/config.proto',
  package='envoy.config.filter.http.jwt_authn.v2alpha',
  syntax='proto3',
  serialized_options=b'\n8io.envoyproxy.envoy.config.filter.http.jwt_authn.v2alphaB\013ConfigProtoP\001\362\230\376\217\005,\022*envoy.extensions.filters.http.jwt_authn.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/config/filter/http/jwt_authn/v2alpha/config.proto\x12*envoy.config.filter.http.jwt_authn.v2alpha\x1a\x1c\x65nvoy/api/v2/core/base.proto\x1a envoy/api/v2/core/http_uri.proto\x1a)envoy/api/v2/route/route_components.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\x8b\x03\n\x0bJwtProvider\x12\x17\n\x06issuer\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x11\n\taudiences\x18\x02 \x03(\t\x12M\n\x0bremote_jwks\x18\x03 \x01(\x0b\x32\x36.envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwksH\x00\x12\x33\n\nlocal_jwks\x18\x04 \x01(\x0b\x32\x1d.envoy.api.v2.core.DataSourceH\x00\x12\x0f\n\x07\x66orward\x18\x05 \x01(\x08\x12K\n\x0c\x66rom_headers\x18\x06 \x03(\x0b\x32\x35.envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader\x12\x13\n\x0b\x66rom_params\x18\x07 \x03(\t\x12\x1e\n\x16\x66orward_payload_header\x18\x08 \x01(\t\x12\x1b\n\x13payload_in_metadata\x18\t \x01(\tB\x1c\n\x15jwks_source_specifier\x12\x03\xf8\x42\x01\"m\n\nRemoteJwks\x12,\n\x08http_uri\x18\x01 \x01(\x0b\x32\x1a.envoy.api.v2.core.HttpUri\x12\x31\n\x0e\x63\x61\x63he_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"8\n\tJwtHeader\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12\x14\n\x0cvalue_prefix\x18\x02 \x01(\t\"A\n\x15ProviderWithAudiences\x12\x15\n\rprovider_name\x18\x01 \x01(\t\x12\x11\n\taudiences\x18\x02 \x03(\t\"\xc0\x03\n\x0eJwtRequirement\x12\x17\n\rprovider_name\x18\x01 \x01(\tH\x00\x12\x63\n\x16provider_and_audiences\x18\x02 \x01(\x0b\x32\x41.envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiencesH\x00\x12X\n\x0crequires_any\x18\x03 \x01(\x0b\x32@.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrListH\x00\x12Y\n\x0crequires_all\x18\x04 \x01(\x0b\x32\x41.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndListH\x00\x12\x39\n\x17\x61llow_missing_or_failed\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12/\n\rallow_missing\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\x0f\n\rrequires_type\"r\n\x14JwtRequirementOrList\x12Z\n\x0crequirements\x18\x01 \x03(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\"s\n\x15JwtRequirementAndList\x12Z\n\x0crequirements\x18\x01 \x03(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementB\x08\xfa\x42\x05\x92\x01\x02\x08\x02\"\x98\x01\n\x0fRequirementRule\x12\x37\n\x05match\x18\x01 \x01(\x0b\x32\x1e.envoy.api.v2.route.RouteMatchB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12L\n\x08requires\x18\x02 \x01(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement\"\xf2\x01\n\x0f\x46ilterStateRule\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02 \x01\x12[\n\x08requires\x18\x03 \x03(\x0b\x32I.envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry\x1ak\n\rRequiresEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12I\n\x05value\x18\x02 \x01(\x0b\x32:.envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement:\x02\x38\x01\"\xa3\x03\n\x11JwtAuthentication\x12_\n\tproviders\x18\x01 \x03(\x0b\x32L.envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry\x12J\n\x05rules\x18\x02 \x03(\x0b\x32;.envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule\x12W\n\x12\x66ilter_state_rules\x18\x03 \x01(\x0b\x32;.envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule\x12\x1d\n\x15\x62ypass_cors_preflight\x18\x04 \x01(\x08\x1ai\n\x0eProvidersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x46\n\x05value\x18\x02 \x01(\x0b\x32\x37.envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider:\x02\x38\x01\x42\x83\x01\n8io.envoyproxy.envoy.config.filter.http.jwt_authn.v2alphaB\x0b\x43onfigProtoP\x01\xf2\x98\xfe\x8f\x05,\x12*envoy.extensions.filters.http.jwt_authn.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_base__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2.DESCRIPTOR,envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_JWTPROVIDER = _descriptor.Descriptor(
  name='JwtProvider',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='issuer', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.issuer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audiences', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.audiences', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remote_jwks', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.remote_jwks', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_jwks', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.local_jwks', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.forward', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_headers', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.from_headers', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_params', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.from_params', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='forward_payload_header', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.forward_payload_header', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload_in_metadata', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.payload_in_metadata', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='jwks_source_specifier', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider.jwks_source_specifier',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=360,
  serialized_end=755,
)


_REMOTEJWKS = _descriptor.Descriptor(
  name='RemoteJwks',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_uri', full_name='envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks.http_uri', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cache_duration', full_name='envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks.cache_duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=757,
  serialized_end=866,
)


_JWTHEADER = _descriptor.Descriptor(
  name='JwtHeader',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value_prefix', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader.value_prefix', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=868,
  serialized_end=924,
)


_PROVIDERWITHAUDIENCES = _descriptor.Descriptor(
  name='ProviderWithAudiences',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audiences', full_name='envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences.audiences', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=926,
  serialized_end=991,
)


_JWTREQUIREMENT = _descriptor.Descriptor(
  name='JwtRequirement',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='provider_name', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.provider_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='provider_and_audiences', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.provider_and_audiences', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_any', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.requires_any', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires_all', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.requires_all', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_missing_or_failed', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.allow_missing_or_failed', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_missing', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.allow_missing', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='requires_type', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement.requires_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=994,
  serialized_end=1442,
)


_JWTREQUIREMENTORLIST = _descriptor.Descriptor(
  name='JwtRequirementOrList',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requirements', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrList.requirements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1444,
  serialized_end=1558,
)


_JWTREQUIREMENTANDLIST = _descriptor.Descriptor(
  name='JwtRequirementAndList',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requirements', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndList.requirements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1560,
  serialized_end=1675,
)


_REQUIREMENTRULE = _descriptor.Descriptor(
  name='RequirementRule',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='match', full_name='envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule.match', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires', full_name='envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule.requires', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1678,
  serialized_end=1830,
)


_FILTERSTATERULE_REQUIRESENTRY = _descriptor.Descriptor(
  name='RequiresEntry',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1968,
  serialized_end=2075,
)

_FILTERSTATERULE = _descriptor.Descriptor(
  name='FilterStateRule',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002 \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requires', full_name='envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.requires', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_FILTERSTATERULE_REQUIRESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1833,
  serialized_end=2075,
)


_JWTAUTHENTICATION_PROVIDERSENTRY = _descriptor.Descriptor(
  name='ProvidersEntry',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2392,
  serialized_end=2497,
)

_JWTAUTHENTICATION = _descriptor.Descriptor(
  name='JwtAuthentication',
  full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='providers', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.providers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rules', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.rules', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_state_rules', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.filter_state_rules', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bypass_cors_preflight', full_name='envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.bypass_cors_preflight', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_JWTAUTHENTICATION_PROVIDERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2078,
  serialized_end=2497,
)

_JWTPROVIDER.fields_by_name['remote_jwks'].message_type = _REMOTEJWKS
_JWTPROVIDER.fields_by_name['local_jwks'].message_type = envoy_dot_api_dot_v2_dot_core_dot_base__pb2._DATASOURCE
_JWTPROVIDER.fields_by_name['from_headers'].message_type = _JWTHEADER
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier'].fields.append(
  _JWTPROVIDER.fields_by_name['remote_jwks'])
_JWTPROVIDER.fields_by_name['remote_jwks'].containing_oneof = _JWTPROVIDER.oneofs_by_name['jwks_source_specifier']
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier'].fields.append(
  _JWTPROVIDER.fields_by_name['local_jwks'])
_JWTPROVIDER.fields_by_name['local_jwks'].containing_oneof = _JWTPROVIDER.oneofs_by_name['jwks_source_specifier']
_REMOTEJWKS.fields_by_name['http_uri'].message_type = envoy_dot_api_dot_v2_dot_core_dot_http__uri__pb2._HTTPURI
_REMOTEJWKS.fields_by_name['cache_duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_JWTREQUIREMENT.fields_by_name['provider_and_audiences'].message_type = _PROVIDERWITHAUDIENCES
_JWTREQUIREMENT.fields_by_name['requires_any'].message_type = _JWTREQUIREMENTORLIST
_JWTREQUIREMENT.fields_by_name['requires_all'].message_type = _JWTREQUIREMENTANDLIST
_JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_JWTREQUIREMENT.fields_by_name['allow_missing'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['provider_name'])
_JWTREQUIREMENT.fields_by_name['provider_name'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['provider_and_audiences'])
_JWTREQUIREMENT.fields_by_name['provider_and_audiences'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['requires_any'])
_JWTREQUIREMENT.fields_by_name['requires_any'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['requires_all'])
_JWTREQUIREMENT.fields_by_name['requires_all'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'])
_JWTREQUIREMENT.fields_by_name['allow_missing_or_failed'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENT.oneofs_by_name['requires_type'].fields.append(
  _JWTREQUIREMENT.fields_by_name['allow_missing'])
_JWTREQUIREMENT.fields_by_name['allow_missing'].containing_oneof = _JWTREQUIREMENT.oneofs_by_name['requires_type']
_JWTREQUIREMENTORLIST.fields_by_name['requirements'].message_type = _JWTREQUIREMENT
_JWTREQUIREMENTANDLIST.fields_by_name['requirements'].message_type = _JWTREQUIREMENT
_REQUIREMENTRULE.fields_by_name['match'].message_type = envoy_dot_api_dot_v2_dot_route_dot_route__components__pb2._ROUTEMATCH
_REQUIREMENTRULE.fields_by_name['requires'].message_type = _JWTREQUIREMENT
_FILTERSTATERULE_REQUIRESENTRY.fields_by_name['value'].message_type = _JWTREQUIREMENT
_FILTERSTATERULE_REQUIRESENTRY.containing_type = _FILTERSTATERULE
_FILTERSTATERULE.fields_by_name['requires'].message_type = _FILTERSTATERULE_REQUIRESENTRY
_JWTAUTHENTICATION_PROVIDERSENTRY.fields_by_name['value'].message_type = _JWTPROVIDER
_JWTAUTHENTICATION_PROVIDERSENTRY.containing_type = _JWTAUTHENTICATION
_JWTAUTHENTICATION.fields_by_name['providers'].message_type = _JWTAUTHENTICATION_PROVIDERSENTRY
_JWTAUTHENTICATION.fields_by_name['rules'].message_type = _REQUIREMENTRULE
_JWTAUTHENTICATION.fields_by_name['filter_state_rules'].message_type = _FILTERSTATERULE
DESCRIPTOR.message_types_by_name['JwtProvider'] = _JWTPROVIDER
DESCRIPTOR.message_types_by_name['RemoteJwks'] = _REMOTEJWKS
DESCRIPTOR.message_types_by_name['JwtHeader'] = _JWTHEADER
DESCRIPTOR.message_types_by_name['ProviderWithAudiences'] = _PROVIDERWITHAUDIENCES
DESCRIPTOR.message_types_by_name['JwtRequirement'] = _JWTREQUIREMENT
DESCRIPTOR.message_types_by_name['JwtRequirementOrList'] = _JWTREQUIREMENTORLIST
DESCRIPTOR.message_types_by_name['JwtRequirementAndList'] = _JWTREQUIREMENTANDLIST
DESCRIPTOR.message_types_by_name['RequirementRule'] = _REQUIREMENTRULE
DESCRIPTOR.message_types_by_name['FilterStateRule'] = _FILTERSTATERULE
DESCRIPTOR.message_types_by_name['JwtAuthentication'] = _JWTAUTHENTICATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JwtProvider = _reflection.GeneratedProtocolMessageType('JwtProvider', (_message.Message,), {
  'DESCRIPTOR' : _JWTPROVIDER,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtProvider)
  })
_sym_db.RegisterMessage(JwtProvider)

RemoteJwks = _reflection.GeneratedProtocolMessageType('RemoteJwks', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEJWKS,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.RemoteJwks)
  })
_sym_db.RegisterMessage(RemoteJwks)

JwtHeader = _reflection.GeneratedProtocolMessageType('JwtHeader', (_message.Message,), {
  'DESCRIPTOR' : _JWTHEADER,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtHeader)
  })
_sym_db.RegisterMessage(JwtHeader)

ProviderWithAudiences = _reflection.GeneratedProtocolMessageType('ProviderWithAudiences', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERWITHAUDIENCES,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.ProviderWithAudiences)
  })
_sym_db.RegisterMessage(ProviderWithAudiences)

JwtRequirement = _reflection.GeneratedProtocolMessageType('JwtRequirement', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENT,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirement)
  })
_sym_db.RegisterMessage(JwtRequirement)

JwtRequirementOrList = _reflection.GeneratedProtocolMessageType('JwtRequirementOrList', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENTORLIST,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementOrList)
  })
_sym_db.RegisterMessage(JwtRequirementOrList)

JwtRequirementAndList = _reflection.GeneratedProtocolMessageType('JwtRequirementAndList', (_message.Message,), {
  'DESCRIPTOR' : _JWTREQUIREMENTANDLIST,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtRequirementAndList)
  })
_sym_db.RegisterMessage(JwtRequirementAndList)

RequirementRule = _reflection.GeneratedProtocolMessageType('RequirementRule', (_message.Message,), {
  'DESCRIPTOR' : _REQUIREMENTRULE,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.RequirementRule)
  })
_sym_db.RegisterMessage(RequirementRule)

FilterStateRule = _reflection.GeneratedProtocolMessageType('FilterStateRule', (_message.Message,), {

  'RequiresEntry' : _reflection.GeneratedProtocolMessageType('RequiresEntry', (_message.Message,), {
    'DESCRIPTOR' : _FILTERSTATERULE_REQUIRESENTRY,
    '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule.RequiresEntry)
    })
  ,
  'DESCRIPTOR' : _FILTERSTATERULE,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.FilterStateRule)
  })
_sym_db.RegisterMessage(FilterStateRule)
_sym_db.RegisterMessage(FilterStateRule.RequiresEntry)

JwtAuthentication = _reflection.GeneratedProtocolMessageType('JwtAuthentication', (_message.Message,), {

  'ProvidersEntry' : _reflection.GeneratedProtocolMessageType('ProvidersEntry', (_message.Message,), {
    'DESCRIPTOR' : _JWTAUTHENTICATION_PROVIDERSENTRY,
    '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication.ProvidersEntry)
    })
  ,
  'DESCRIPTOR' : _JWTAUTHENTICATION,
  '__module__' : 'envoy.config.filter.http.jwt_authn.v2alpha.config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.jwt_authn.v2alpha.JwtAuthentication)
  })
_sym_db.RegisterMessage(JwtAuthentication)
_sym_db.RegisterMessage(JwtAuthentication.ProvidersEntry)


DESCRIPTOR._options = None
_JWTPROVIDER.oneofs_by_name['jwks_source_specifier']._options = None
_JWTPROVIDER.fields_by_name['issuer']._options = None
_JWTHEADER.fields_by_name['name']._options = None
_JWTREQUIREMENTORLIST.fields_by_name['requirements']._options = None
_JWTREQUIREMENTANDLIST.fields_by_name['requirements']._options = None
_REQUIREMENTRULE.fields_by_name['match']._options = None
_FILTERSTATERULE_REQUIRESENTRY._options = None
_FILTERSTATERULE.fields_by_name['name']._options = None
_JWTAUTHENTICATION_PROVIDERSENTRY._options = None
# @@protoc_insertion_point(module_scope)
